==> ejc-probuilddiary-impl-3.0.0-20230516.143331-113-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonExamineEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-原材料检验、时间、试块及见证取样送检等情况（取样员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_examine")
public class PersonExamineEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="mold_id")
    private Long moldId; // 工作类型id
    @TableField(value="mold_name")
    private String moldName; // 工作类型名称
    @TableField(value="mold_code")
    private String moldCode; // 工作类型编码
    @TableField(value="make_id")
    private Long makeId; // 试块制作情况id
    @TableField(value="make_name")
    private String makeName; // 试块制作情况名称
    @TableField(value="make_code")
    private String makeCode; // 试块制作情况编码
    @TableField(value="inspect_id")
    private Long inspectId; // 试块送检情况id
    @TableField(value="inspect_name")
    private String inspectName; // 试块送检情况名称
    @TableField(value="inspect_code")
    private String inspectCode; // 试块送检情况编码
    @TableField(value="examine_id")
    private Long examineId; // 现场检测名称id
    @TableField(value="examine_name")
    private String examineName; // 现场检测名称名称
    @TableField(value="examine_code")
    private String examineCode; // 现场检测名称编码
    @TableField(value="examine_num")
    private BigDecimal examineNum; // 数量
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getMoldId() {
        return moldId;
    }

    public void setMoldId(Long moldId) {
        this.moldId = moldId;
    }
    public String getMoldName() {
        return moldName;
    }

    public void setMoldName(String moldName) {
        this.moldName = moldName;
    }
    public String getMoldCode() {
        return moldCode;
    }

    public void setMoldCode(String moldCode) {
        this.moldCode = moldCode;
    }
    public Long getMakeId() {
        return makeId;
    }

    public void setMakeId(Long makeId) {
        this.makeId = makeId;
    }
    public String getMakeName() {
        return makeName;
    }

    public void setMakeName(String makeName) {
        this.makeName = makeName;
    }
    public String getMakeCode() {
        return makeCode;
    }

    public void setMakeCode(String makeCode) {
        this.makeCode = makeCode;
    }
    public Long getInspectId() {
        return inspectId;
    }

    public void setInspectId(Long inspectId) {
        this.inspectId = inspectId;
    }
    public String getInspectName() {
        return inspectName;
    }

    public void setInspectName(String inspectName) {
        this.inspectName = inspectName;
    }
    public String getInspectCode() {
        return inspectCode;
    }

    public void setInspectCode(String inspectCode) {
        this.inspectCode = inspectCode;
    }
    public Long getExamineId() {
        return examineId;
    }

    public void setExamineId(Long examineId) {
        this.examineId = examineId;
    }
    public String getExamineName() {
        return examineName;
    }

    public void setExamineName(String examineName) {
        this.examineName = examineName;
    }
    public String getExamineCode() {
        return examineCode;
    }

    public void setExamineCode(String examineCode) {
        this.examineCode = examineCode;
    }
    public BigDecimal getExamineNum() {
        return examineNum;
    }

    public void setExamineNum(BigDecimal examineNum) {
        this.examineNum = examineNum;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20230712.030237-128-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonExamineEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-检验试验情况（取样员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_examine")
public class PersonExamineEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="mold_id")
    private Long moldId; // 工作类型id
    @TableField(value="mold_name")
    private String moldName; // 工作类型名称
    @TableField(value="mold_code")
    private String moldCode; // 工作类型编码
    @TableField(value="make_id")
    private Long makeId; // 试块制作情况id
    @TableField(value="make_name")
    private String makeName; // 试块制作情况名称
    @TableField(value="make_code")
    private String makeCode; // 试块制作情况编码
    @TableField(value="inspect_id")
    private Long inspectId; // 试块送检情况id
    @TableField(value="inspect_name")
    private String inspectName; // 试块送检情况名称
    @TableField(value="inspect_code")
    private String inspectCode; // 试块送检情况编码
    @TableField(value="examine_id")
    private Long examineId; // 现场检测名称id
    @TableField(value="examine_name")
    private String examineName; // 现场检测名称名称
    @TableField(value="examine_code")
    private String examineCode; // 现场检测名称编码
    @TableField(value="examine_num")
    private BigDecimal examineNum; // 数量
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目
    @TableField(value = "examine_memo")
    private String examineMemo;//工作描述

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getMoldId() {
        return moldId;
    }

    public void setMoldId(Long moldId) {
        this.moldId = moldId;
    }
    public String getMoldName() {
        return moldName;
    }

    public void setMoldName(String moldName) {
        this.moldName = moldName;
    }
    public String getMoldCode() {
        return moldCode;
    }

    public void setMoldCode(String moldCode) {
        this.moldCode = moldCode;
    }
    public Long getMakeId() {
        return makeId;
    }

    public void setMakeId(Long makeId) {
        this.makeId = makeId;
    }
    public String getMakeName() {
        return makeName;
    }

    public void setMakeName(String makeName) {
        this.makeName = makeName;
    }
    public String getMakeCode() {
        return makeCode;
    }

    public void setMakeCode(String makeCode) {
        this.makeCode = makeCode;
    }
    public Long getInspectId() {
        return inspectId;
    }

    public void setInspectId(Long inspectId) {
        this.inspectId = inspectId;
    }
    public String getInspectName() {
        return inspectName;
    }

    public void setInspectName(String inspectName) {
        this.inspectName = inspectName;
    }
    public String getInspectCode() {
        return inspectCode;
    }

    public void setInspectCode(String inspectCode) {
        this.inspectCode = inspectCode;
    }
    public Long getExamineId() {
        return examineId;
    }

    public void setExamineId(Long examineId) {
        this.examineId = examineId;
    }
    public String getExamineName() {
        return examineName;
    }

    public void setExamineName(String examineName) {
        this.examineName = examineName;
    }
    public String getExamineCode() {
        return examineCode;
    }

    public void setExamineCode(String examineCode) {
        this.examineCode = examineCode;
    }
    public BigDecimal getExamineNum() {
        return examineNum;
    }

    public void setExamineNum(BigDecimal examineNum) {
        this.examineNum = examineNum;
    }

    public String getExamineMemo() {
        return examineMemo;
    }

    public void setExamineMemo(String examineMemo) {
        this.examineMemo = examineMemo;
    }
}
